==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_sv-SE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Komplett</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Begränsningsaxel...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>Sätt en axelbegränsning mellan två objekt</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Självtest ...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Kör ett självtest för att kontrollera om programmet fungerar</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>&amp;Ritning</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>S&amp;kiss</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>R&amp;endering</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Skissning</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Skiss baserad</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Primitiver</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Parametrisk</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Objekt utseende</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Trådverktyg</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_sv-SE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv-SE" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Komplett</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Begränsningsaxel...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>Sätt en axelbegränsning mellan två objekt</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Självtest ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Kör ett självtest för att kontrollera om programmet fungerar</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>&amp;Ritning</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>S&amp;kiss</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>R&amp;endering</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Skissning</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Skiss baserad</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Primitiver</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Parametrisk</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Objekt utseende</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Trådverktyg</translation>
    </message>
  </context>
</TS>
